@@ -2,7 +2,10 @@ import ast
 import inspect
 from functools import partial
 
-from lambdex.utils.ast import *
+from lambdex._aliases import get_aliases, COMPARATORS
+aliases = get_aliases()
+
+from lambdex.utils.ast import check_as, copy_lineinfo, check_compare, cast_to_lvalue
 from lambdex.utils.registry import FunctionRegistry
 
 from .context import Context, ContextFlag
@@ -36,6 +39,11 @@ def _compile_stmts(ctx: Context, stmts):
     return compiled_statements
 
 
+@Rules.register('callee')
+def r_callee(node: ast.Name, ctx: Context):
+    return copy_lineinfo(node, ast.Name(id=ctx.frame.name, ctx=node.ctx))
+
+
 @Rules.register((ast.Lambda, ContextFlag.outermost_lambdex))
 def r_lambda(node: ast.Lambda, ctx: Context):
     ctx.assert_is_instance(node.body, ast.List, "expect '['")
@@ -43,13 +51,14 @@ def r_lambda(node: ast.Lambda, ctx: Context):
     statements = node.body  # type: ast.List
 
     ctx.push_frame()
+    ctx.frame.name = func_name = ctx.select_name_and_use('anonymous')
 
     ctx.assert_(statements.elts, 'empty body', statements)
     compiled_statements = _compile_stmts(ctx, statements.elts)
     detached_functions = ctx.frame.detached_functions
 
     new_function = ast.FunctionDef(
-        name=ctx.select_name_and_use('anonymous'),
+        name=func_name,
         args=node.args,
         body=detached_functions + compiled_statements,
         decorator_list=[],
@@ -103,14 +112,14 @@ def r_if(node: ast.Subscript, ctx: Context, clauses: list):
     ctx.assert_single_head(clauses[0])
 
     for clause in clauses[1:-1]:
-        ctx.assert_name_equals(clause, 'elif_')
+        ctx.assert_name_equals(clause, aliases.elif_)
         ctx.assert_head(clause)
         ctx.assert_single_head(clause)
 
     if not clauses.single():
         clause = clauses[-1]
-        ctx.assert_name_in(clause, ('else_', 'elif_'))
-        if clause.name == 'else_':
+        ctx.assert_name_in(clause, (aliases.else_, aliases.elif_))
+        if clause.name == aliases.else_:
             ctx.assert_no_head(clause)
         else:
             ctx.assert_head(clause)
@@ -119,7 +128,7 @@ def r_if(node: ast.Subscript, ctx: Context, clauses: list):
     curr_node = None
     prev_orelse = []
     for clause in clauses[::-1]:
-        if clause.name == 'else_':
+        if clause.name == aliases.else_:
             prev_orelse = _compile_stmts(ctx, clause.body)
             continue
 
@@ -142,7 +151,7 @@ def r_for(node: ast.Subscript, ctx: Context, clauses: list):
     ctx.assert_head(clauses[0])
     ctx.assert_single_head(clauses[0])
     if len(clauses) == 2:
-        ctx.assert_name_equals(clauses[1], 'else_')
+        ctx.assert_name_equals(clauses[1], aliases.else_)
         ctx.assert_no_head(clauses[1])
 
     target, iter_item = check_compare(ctx, clauses[0].unwrap_head(), ast.In, 2)
@@ -172,7 +181,7 @@ def r_while(node: ast.Subscript, ctx: Context, clauses: list):
     ctx.assert_head(clauses[0])
     ctx.assert_single_head(clauses[0])
     if len(clauses) == 2:
-        ctx.assert_name_equals(clauses[1], 'else_')
+        ctx.assert_name_equals(clauses[1], aliases.else_)
         ctx.assert_no_head(clauses[1])
 
     if len(clauses) == 2:
@@ -193,7 +202,7 @@ def r_while(node: ast.Subscript, ctx: Context, clauses: list):
 @Rules.register(ast.Assign)
 def r_assign(node: ast.Compare, ctx: Context):
     try:
-        *targets, value = check_compare(ctx, node, ast.Lt)
+        *targets, value = check_compare(ctx, node, COMPARATORS[aliases.Assignment])
     except SyntaxError:
         return copy_lineinfo(
             node,
@@ -236,7 +245,7 @@ def r_with(node: ast.Subscript, ctx: Context, clauses: list):
 
     items = []
     for arg in with_clause.head:
-        context_expr, var = check_as(ctx, arg, ast.Gt)
+        context_expr, var = check_as(ctx, arg, COMPARATORS[aliases.As])
         item = ast.withitem(
             context_expr=ctx.compile(context_expr),
             optional_vars=var,
@@ -264,7 +273,7 @@ def r_raise(node: ast.Subscript, ctx: Context, clauses: list):
     cause = None
     if len(clauses) == 2:
         from_clause = clauses[1]
-        ctx.assert_name_equals(from_clause, 'from_')
+        ctx.assert_name_equals(from_clause, aliases.from_)
         ctx.assert_no_head(from_clause)
         ctx.assert_single_body(from_clause)
         cause = ctx.compile(from_clause.unwrap_body())
@@ -289,10 +298,10 @@ def r_try(node: ast.Subscript, ctx: Context, clauses: list):
     final_body = []
     default_except_clause = None
     for clause in clauses[1:]:
-        if clause.name == 'except_':
+        if clause.name == aliases.except_:
             ctx.assert_(
                 not orelse_body and not final_body,
-                "unexpected 'except_'",
+                "unexpected {!r}".format(aliases.except_),
                 clause.node,
             )
 
@@ -304,11 +313,11 @@ def r_try(node: ast.Subscript, ctx: Context, clauses: list):
                 # except with capturing
                 ctx.assert_(
                     default_except_clause is None,
-                    "default 'except_' must be last",
+                    "default {!r} must be last".format(aliases.except_),
                     lambda: default_except_clause.node,
                 )
                 ctx.assert_single_head(clause)
-                type_, name = check_as(ctx, clause.unwrap_head(), ast.Gt, rhs_is_identifier=True)
+                type_, name = check_as(ctx, clause.unwrap_head(), COMPARATORS[aliases.As], rhs_is_identifier=True)
 
             handler = ast.ExceptHandler(
                 type=ctx.compile(type_),
@@ -316,18 +325,18 @@ def r_try(node: ast.Subscript, ctx: Context, clauses: list):
                 body=_compile_stmts(ctx, clause.body),
             )
             handlers.append(copy_lineinfo(clause.node, handler))
-        elif clause.name == 'else_':
+        elif clause.name == aliases.else_:
             ctx.assert_(
                 handlers and not orelse_body and not final_body,
-                "unexpected 'else_'",
+                "unexpected {!r}".format(aliases.else_),
                 clause.node,
             )
             ctx.assert_no_head(clause)
             orelse_body.extend(_compile_stmts(ctx, clause.body))
-        elif clause.name == 'finally_':
+        elif clause.name == aliases.finally_:
             ctx.assert_(
                 not final_body,
-                "unexpected 'finally_'",
+                "unexpected {!r}".format(aliases.finally_),
                 clause.node,
             )
             ctx.assert_no_head(clause)
@@ -337,7 +346,7 @@ def r_try(node: ast.Subscript, ctx: Context, clauses: list):
 
     ctx.assert_(
         handlers or final_body,
-        "'try_' has neither 'except_' clause(s) nor 'finally_' clause",
+        "{!r} has neither {!r} clause(s) nor {!r} clause".format(aliases.try_, aliases.except_, aliases.finally_),
         try_clause.node,
     )
 
