@@ -1,7 +1,7 @@
-from ...utils.logger import getLogger
+from lambdex.fmt.utils.logger import getLogger
 
-from .._stream_base import _StreamWithLog
-from ..definitions import tk, A, TokenInfo, actions
+from lambdex.fmt.core._stream_base import _StreamWithLog
+from lambdex.fmt.core.definitions import tk, A, TokenInfo, actions
 
 logger = getLogger(__name__)
 
@@ -66,8 +66,6 @@ START_TOKENS = frozenset(x.pattern[0] for x in COLLECT_FORWARD + COLLECT_BACKWAR
 class CollectComments(_StreamWithLog):
     def _split_buffer(self):
         comments, others = [], []
-        # for idx,token in self.buffer:
-
         iterator = iter(self.buffer)
 
         def _next():
