@@ -1,5 +1,5 @@
-from ..definitions import tk, A, TokenInfo, actions
-from .._stream_base import _StreamWithLog
+from lambdex.fmt.core.definitions import tk, A, TokenInfo, actions
+from lambdex.fmt.core._stream_base import _StreamWithLog
 
 SUPPRESS_WHITESPACE_AFTER = frozenset([
     A.DECL,
